//=============================================================================
//  MuseScore
//  Linux Music Score Editor
//  $Id:$
//
//  Autotune let you define pitch in cent for notes in a selection 
//  you have done in the score.
//
//  Copyright (C)2008 Werner Schweer and others
//
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License version 2.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
//=============================================================================

//
// This is ECMAScript code (ECMA-262 aka "Java Script")
//
var form;

//---------------------------------------------------------
//    init
//    this function will be called on startup of mscore
//---------------------------------------------------------

function init()
      {
      // print("test script init");
      }


// Apply the given function to all notes in selection
function applyToNotesInSelection()
      {
      var cursor       = new Cursor(curScore);
      var selectionEnd = new Cursor(curScore);
      
      cursor.goToSelectionStart();
      selectionEnd.goToSelectionEnd();
      var startStaff = cursor.staff;
      var endStaff   = selectionEnd.staff;

      for (var staff = startStaff; staff < endStaff; ++staff) {
            cursor.goToSelectionStart();
            for (var v = 0; v < 4; v++) {          
                  cursor.goToSelectionStart(); // set voice to 0
                  cursor.voice = v; //voice has to be set after goTo
                  cursor.staff = staff;

                  while (cursor.tick() < selectionEnd.tick()) {
                        if (cursor.isChord()) {
                              var chord = cursor.chord();
                              var n     = chord.notes;
                              for (var i = 0; i < n; i++) {
                                    var note   = chord.note(i);
                                    changeTuning(note);
                                    }
                              }
                        cursor.next();
                        }
                  }
            }
      }

//pitch notes
function changeTuning(note)
    {
    //Receive notes from the ui
    var tuning = [
	      form.gridLayoutWidget.note01.text,  // C
	      form.gridLayoutWidget.note02.text,  // C# / Db
	      form.gridLayoutWidget.note03.text,  // D
	      form.gridLayoutWidget.note04.text,  // D# / Eb
	      form.gridLayoutWidget.note05.text,  // E
	      form.gridLayoutWidget.note06.text,  // F
	      form.gridLayoutWidget.note07.text,  // F# / Gb
	      form.gridLayoutWidget.note08.text,  // G
	      form.gridLayoutWidget.note09.text,  // G# / Ab
	      form.gridLayoutWidget.note10.text,  // A
	      form.gridLayoutWidget.note11.text,  // A# / Bb
	      form.gridLayoutWidget.note12.text]; // B

    //proceed to the pitch changes
     note.tuning = tuning[note.pitch % 12];
    }
//-------------------------------------------------------------------
//    run
//    this function will be called when activating the
//    plugin menu entry
//
//    global Variables:
//    pluginPath - contains the plugin path; file separator is "/"
//-------------------------------------------------------------------

function run()
      {
      var loader = new QUiLoader(null);
      var file   = new QFile(pluginPath + "/autotune.ui");
      file.open(QIODevice.OpenMode(QIODevice.ReadOnly, QIODevice.Text));
      form = loader.load(file, null);
      form.buttonBox.accepted.connect(applyToNotesInSelection);
      form.show();
      }

//---------------------------------------------------------
//    menu:  defines were the function will be placed
//           in the MuseScore menu structure
//---------------------------------------------------------

var mscorePlugin = {
      menu: 'Plugins.Auto Tune Selection',
      init: init,
      run:  run
      };

mscorePlugin;

